@@ -1,5 +1,5 @@
 #
-# Copyright 2021 Budapest Quantum Computing Group
+# Copyright 2021-2022 Budapest Quantum Computing Group
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,7 +18,7 @@ from typing import Tuple, Any, Generator, Dict
 import numpy as np
 
 from piquasso.api.config import Config
-from piquasso.api.errors import InvalidState, PiquassoException
+from piquasso.api.exceptions import InvalidState, PiquassoException
 from piquasso._math.linalg import is_selfadjoint
 from piquasso._math.fock import cutoff_cardinality, FockOperatorBasis
 
@@ -52,6 +52,9 @@ class FockState(BaseFockState):
         self._density_matrix = self._get_empty()
         self._density_matrix[0, 0] = 1.0
 
+    def _as_mixed(self):
+        return self.copy()
+
     @classmethod
     def from_fock_state(cls, state: BaseFockState) -> "FockState":
         """Instantiation using another :class:`BaseFockState` instance.
@@ -239,6 +242,6 @@ class FockState(BaseFockState):
             np.trace(
                 np.dot(reduced_dm, np.dot(rotated_quadratures, rotated_quadratures))
             ).real
-            - expctation ** 2
+            - expctation**2
         )
         return expctation, variance
