@@ -1,5 +1,5 @@
 #
-# Copyright 2021 Budapest Quantum Computing Group
+# Copyright 2021-2022 Budapest Quantum Computing Group
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,7 +19,7 @@ import numpy as np
 from scipy.linalg import sqrtm
 
 from piquasso.api.config import Config
-from piquasso.api.errors import InvalidState, InvalidParameter, PiquassoException
+from piquasso.api.exceptions import InvalidState, InvalidParameter, PiquassoException
 from piquasso.api.state import State
 
 from piquasso._math.functions import gaussian_wigner_function
@@ -31,7 +31,11 @@ from piquasso._math.symplectic import symplectic_form, xp_symplectic_form
 from piquasso._math.combinatorics import get_occupation_numbers
 from piquasso._math.transformations import from_xxpp_to_xpxp_transformation_matrix
 
-from .probabilities import DensityMatrixCalculation
+from .probabilities import (
+    DensityMatrixCalculation,
+    DisplacedDensityMatrixCalculation,
+    NondisplacedDensityMatrixCalculation,
+)
 
 
 class GaussianState(State):
@@ -184,16 +188,12 @@ class GaussianState(State):
         C = self._C
         G = self._G
 
-        dimensionless_xxpp_covariance_matrix = (
-            2
-            * np.block(
-                [
-                    [(G + C).real, (G + C).imag],
-                    [(G - C).imag, (-G + C).real],
-                ],
-            )
-            + np.identity(2 * self.d)
-        )
+        dimensionless_xxpp_covariance_matrix = 2 * np.block(
+            [
+                [(G + C).real, (G + C).imag],
+                [(G - C).imag, (-G + C).real],
+            ],
+        ) + np.identity(2 * self.d)
 
         return dimensionless_xxpp_covariance_matrix * self._config.hbar
 
@@ -465,7 +465,7 @@ class GaussianState(State):
 
         return self.__class__._from_representation(
             C=self._C,
-            G=(self._G * phase ** 2),
+            G=(self._G * phase**2),
             m=(self._m * phase),
             config=self._config,
         )
@@ -728,13 +728,25 @@ class GaussianState(State):
         # TODO: calculate the variance.
         return first_moment
 
+    def _is_displaced(self) -> bool:
+        return not np.allclose(self._m, 0.0)
+
+    def _get_density_matrix_calculation(self) -> DensityMatrixCalculation:
+        if self._is_displaced():
+            return DisplacedDensityMatrixCalculation(
+                complex_displacement=self.complex_displacement,
+                complex_covariance=self.complex_covariance,
+                loop_hafnian_function=self._config.loop_hafnian_function,
+            )
+
+        return NondisplacedDensityMatrixCalculation(
+            complex_covariance=self.complex_covariance,
+            hafnian_function=self._config.hafnian_function,
+        )
+
     @property
     def density_matrix(self) -> np.ndarray:
-        calculation = DensityMatrixCalculation(
-            complex_displacement=self.complex_displacement,
-            complex_covariance=self.complex_covariance,
-            loop_hafnian_function=self._config.loop_hafnian_function,
-        )
+        calculation = self._get_density_matrix_calculation()
 
         return calculation.get_density_matrix(
             get_occupation_numbers(d=self.d, cutoff=self._config.cutoff)
@@ -797,11 +809,7 @@ class GaussianState(State):
                 f"occupation_number='{occupation_number}'."
             )
 
-        calculation = DensityMatrixCalculation(
-            self.complex_displacement,
-            self.complex_covariance,
-            loop_hafnian_function=self._config.loop_hafnian_function,
-        )
+        calculation = self._get_density_matrix_calculation()
 
         return calculation.get_density_matrix_element(
             bra=occupation_number,
@@ -810,11 +818,7 @@ class GaussianState(State):
 
     @property
     def fock_probabilities(self) -> np.ndarray:
-        calculation = DensityMatrixCalculation(
-            complex_displacement=self.complex_displacement,
-            complex_covariance=self.complex_covariance,
-            loop_hafnian_function=self._config.loop_hafnian_function,
-        )
+        calculation = self._get_density_matrix_calculation()
 
         return calculation.get_particle_number_detection_probabilities(
             get_occupation_numbers(d=self.d, cutoff=self._config.cutoff)
