@@ -1,5 +1,5 @@
 #
-# Copyright 2021 Budapest Quantum Computing Group
+# Copyright 2021-2022 Budapest Quantum Computing Group
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -21,9 +21,9 @@ import random
 import numpy as np
 
 from piquasso._math.permanent import glynn_gray_permanent
-from piquasso._math.hafnian import loop_hafnian
+from piquasso._math.hafnian import hafnian_with_reduction, loop_hafnian_with_reduction
 
-from piquasso.api.typing import PermanentFunction, HafnianFunction
+from piquasso.api.typing import PermanentFunction, HafnianFunction, LoopHafnianFunction
 
 from piquasso.core import _mixins
 
@@ -41,7 +41,8 @@ class Config(_mixins.CodeMixin):
         cutoff: int = 4,
         measurement_cutoff: int = 5,
         permanent_function: PermanentFunction = glynn_gray_permanent,
-        loop_hafnian_function: HafnianFunction = loop_hafnian,
+        hafnian_function: HafnianFunction = hafnian_with_reduction,
+        loop_hafnian_function: LoopHafnianFunction = loop_hafnian_with_reduction,
     ):
         self._original_seed_sequence = seed_sequence
         self.seed_sequence = seed_sequence or int.from_bytes(
@@ -53,6 +54,7 @@ class Config(_mixins.CodeMixin):
         self.cutoff = cutoff
         self.measurement_cutoff = measurement_cutoff
         self.permanent_function = permanent_function
+        self.hafnian_function = hafnian_function
         self.loop_hafnian_function = loop_hafnian_function
 
     def __eq__(self, other: object) -> bool:
