@@ -1,5 +1,5 @@
 #
-# Copyright 2021 Budapest Quantum Computing Group
+# Copyright 2021-2022 Budapest Quantum Computing Group
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,7 +18,7 @@ from typing import Collection, Tuple, Union, Any
 
 from piquasso.core import _context
 
-from .errors import InvalidModes, PiquassoException
+from .exceptions import InvalidModes, PiquassoException
 
 if typing.TYPE_CHECKING:
     from piquasso.api.instruction import Instruction
