@@ -1,5 +1,5 @@
 #
-# Copyright 2021 Budapest Quantum Computing Group
+# Copyright 2021-2022 Budapest Quantum Computing Group
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,4 +19,5 @@ from typing import Callable, Tuple
 
 
 PermanentFunction = Callable[[np.ndarray, Tuple[int, ...], Tuple[int, ...]], float]
-HafnianFunction = Callable[[np.ndarray], float]
+HafnianFunction = Callable[[np.ndarray, Tuple[int, ...]], float]
+LoopHafnianFunction = Callable[[np.ndarray, np.ndarray, Tuple[int, ...]], float]
